@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2013 Index Data.
+ * Copyright (C) Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -34,6 +34,7 @@
 #include <yaz/wrbuf.h>
 #include <yaz/zoom.h>
 #include <yaz/srw.h>
+#include <yaz/cookie.h>
 #include <yaz/mutex.h>
 
 #define SHPTR 1
@@ -102,6 +103,7 @@ struct ZOOM_connection_p {
     ZOOM_Event m_queue_back;
     zoom_sru_mode sru_mode;
     int no_redirects; /* 0 for no redirects. >0 for number of redirects */
+    yaz_cookies_t cookies;
 
     int log_details;
     int log_api;
